@@ -14,7 +14,6 @@
 # along with this library.  If not, see <http://www.gnu.org/licenses/>.
 
 require 'milter/manager/init-detector'
-require 'milter/manager/clamav-milter-socket-detector'
 
 module Milter::Manager
   class DebianInitDetector
@@ -25,12 +24,12 @@ module Milter::Manager
     end
 
     def enabled?
-      @variables["ENABLED"] != "0"
+      @variables["ENABLED"] != "0" and
+        !(clamav_milter_0_95_or_later? and clamav_milter_example?)
     end
 
     def detect_clamav_milter_connection_spec
-      conf = clamav_milter_conf || "/etc/clamav/clamav-milter.conf"
-      Milter::Manager::ClamAVMilterSocketDetector.new(conf).detect
+      clamav_milter_config_parser.milter_socket
     end
 
     def clamav_milter?
@@ -43,6 +42,10 @@ module Milter::Manager
          @variables["CLAMAVMILTERCONF"])
     end
 
+    def milter_greylist?
+      @script_name == "milter-greylist"
+    end
+
     private
     def parse_custom_conf
       parse_default_conf(default_conf)
@@ -68,7 +71,9 @@ module Milter::Manager
     end
 
     def clamav_milter_conf
-      @variables["CLAMAVCONF"] || @variables["CLAMAVMILTERCONF"]
+      @variables["CLAMAVCONF"] ||
+        @variables["CLAMAVMILTERCONF"] ||
+        "/etc/clamav/clamav-milter.conf"
     end
 
     def guess_spec
@@ -101,5 +106,10 @@ module Milter::Manager
     def default_dir
       "/etc/default"
     end
+
+    def milter_greylist_conf
+      extract_parameter_from_flags(@variables["OPTIONS"], "-f") ||
+        "/etc/milter-greylist/greylist.conf"
+    end
   end
 end
