@@ -13,6 +13,9 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this library.  If not, see <http://www.gnu.org/licenses/>.
 
+require 'milter/manager/clamav-milter-config-parser'
+require 'milter/manager/milter-greylist-config-parser'
+
 module Milter::Manager
   module Detector
     attr_reader :name, :variables
@@ -37,7 +40,9 @@ module Milter::Manager
           spec = spec.gsub(/\A(?:(unix|local):)+/, '\\1:')
           milter.connection_spec = spec
         end
+        apply_before_block(milter)
         yield(milter) if block_given?
+        apply_after_block(milter)
       end
     end
 
@@ -49,10 +54,20 @@ module Milter::Manager
       "start"
     end
 
+    def detect_clamav_milter_connection_spec
+      clamav_milter_config_parser.milter_socket
+    end
+
+    def clamav_milter_example?
+      clamav_milter_config_parser.example?
+    end
+
     private
     def init_variables
       @name = nil
       @variables = {}
+      @clamav_milter_config_parser = nil
+      @milter_greylist_config_parser = nil
     end
 
     def set_variable(name, unnormalized_value)
@@ -83,9 +98,9 @@ module Milter::Manager
 
     def extract_variables(output, content, options={})
       if options[:accept_lower_case]
-        variable_definition_re = /\b([A-Za-z\d_]+)=(".*?"|\S*)/
+        variable_definition_re = /\b([A-Za-z\d_]+)=(".*?"|'.*?'|\S*)/
       else
-        variable_definition_re = /\b([A-Z\d_]+)=(".*?"|\S*)/
+        variable_definition_re = /\b([A-Z\d_]+)=(".*?"|'.*?'|\S*)/
       end
 
       content.each_line do |line|
@@ -99,7 +114,7 @@ module Milter::Manager
     end
 
     def normalize_variable_value(value)
-      value = value.sub(/\A"(.*)"\z/, '\\1')
+      value = value.sub(/\A([\"\'])(.*)\1\z/, '\2')
       return nil if /\A\$\d+\z/ =~ value
       variable_expand_re = /\$(\{?)([a-zA-Z\d_]+)(\}?)/
       value.gsub(variable_expand_re) do |matched|
@@ -137,5 +152,32 @@ module Milter::Manager
     def shell_variable?(string)
       /\A\$/ =~ string
     end
+
+    def apply_before_block(milter)
+      if respond_to?(:milter_greylist?) and milter_greylist?
+        milter_greylist_config_parser.apply(milter)
+      end
+    end
+
+    def apply_after_block(milter)
+    end
+
+    def clamav_milter_config_parser
+      if @clamav_milter_config_parser.nil?
+        @clamav_milter_config_parser =
+          Milter::Manager::ClamAVMilterConfigParser.new
+        @clamav_milter_config_parser.parse(clamav_milter_conf)
+      end
+      @clamav_milter_config_parser
+    end
+
+    def milter_greylist_config_parser
+      if @milter_greylist_config_parser.nil?
+        @milter_greylist_config_parser =
+          Milter::Manager::MilterGreylistConfigParser.new
+        @milter_greylist_config_parser.parse(milter_greylist_conf)
+      end
+      @milter_greylist_config_parser
+    end
   end
 end
