@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2008-2009  Kouhei Sutou <kou@cozmixng.org>
+# Copyright (C) 2008-2009  Kouhei Sutou <kou@clear-code.com>
 #
 # This library is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -16,7 +16,7 @@
 # along with this library.  If not, see <http://www.gnu.org/licenses/>.
 
 class TestDebianInitDetector < Test::Unit::TestCase
-  include MilterTestUtils
+  include MilterDetectorTestUtils
 
   def setup
     @configuration = Milter::Manager::Configuration.new
@@ -90,6 +90,8 @@ class TestDebianInitDetector < Test::Unit::TestCase
     detector.detect
     assert_equal({
                    "Provides" => "milter-manager",
+                   "Required-Start" => "$local_fs $remote_fs $network $syslog",
+                   "Required-Stop" => "$local_fs $remote_fs $network $syslog",
                    "Default-Start" => "2 3 4 5",
                    "Default-Stop" => "0 1 6",
                    "Short-Description" => "milter-manager's init script",
@@ -215,7 +217,7 @@ EOM
                   "unix:/var/lib/amavis/amavisd-new-milter.sock"]])
   end
 
-  def test_apply_clamav_milter_style
+  def test_apply_clamav_milter_before_0_95_style
     (@init_d + "clamav-milter").open("w") do |file|
       file << <<-EOM
 #!/bin/sh
@@ -275,6 +277,49 @@ EOM
                   "local:/var/run/clamav/clamav-milter.ctl"]])
   end
 
+  def test_apply_clamav_milter_since_0_95_style
+    clamav_milter_conf = @tmp_dir + "clamav-milter.conf"
+    (@init_d + "clamav-milter").open("w") do |file|
+      file << clamav_milter_since_0_95_init_header(clamav_milter_conf.to_s)
+    end
+
+    clamav_milter_conf.open("w") do |conf|
+      conf << <<-EOC
+#Automatically Generated by clamav-milter postinst
+#To reconfigure clamav-milter run #dpkg-reconfigure clamav-milter
+#Please read /usr/share/doc/clamav-base/README.Debian.gz for details
+MilterSocket /var/run/clamav/milter.ctl
+FixStaleSocket true
+User clamav
+AllowSupplementaryGroups true
+ReadTimeout 180
+Foreground false
+PidFile /var/run/clamav/clamav-milter.pid
+ClamdSocket unix:/var/run/clamav/clamd.ctl
+OnClean Accept
+OnInfected Quarantine
+OnFail Defer
+AddHeader false
+LogSyslog true
+LogFacility LOG_LOCAL6
+LogVerbose false
+LogInfected Off
+MaxFileSize 25M
+TemporaryDirectory /tmp
+EOC
+    end
+
+    detector = debain_init_detector("clamav-milter")
+    detector.detect
+    detector.apply(@loader)
+    assert_eggs([["clamav-milter",
+                  "Clam AntiVirus milter interface",
+                  true,
+                  (@init_d + "clamav-milter").to_s,
+                  "start",
+                  "unix:/var/run/clamav/milter.ctl"]])
+  end
+
   def test_apply_dkim_filter_style
     (@init_d + "dkim-filter").open("w") do |file|
       file << <<-EOM
@@ -479,15 +524,83 @@ EOC
     (top + "data" + "init.d" + "debian" + "milter-manager").read
   end
 
-  def assert_eggs(expected_eggs)
-    egg_info = @configuration.eggs.collect do |egg|
-      [egg.name,
-       egg.description,
-       egg.enabled?,
-       egg.command,
-       egg.command_options,
-       egg.connection_spec]
-    end
-    assert_equal(expected_eggs, egg_info)
+  def clamav_milter_since_0_95_init_header(clamav_milter_conf)
+    <<-EOS
+#!/bin/sh
+### BEGIN INIT INFO
+# Provides:          clamav-milter
+# Required-Start:    $syslog
+# Should-Start:      clamav-daemon
+# Required-Stop:
+# Should-Stop:       
+# Default-Start:     2 3 4 5
+# Default-Stop:      0 6
+# Short-Description: ClamAV virus milter
+# Description:       Clam AntiVirus milter interface
+### END INIT INFO
+
+# edit /etc/default/clamav-milter for options
+
+PATH=/sbin:/bin:/usr/sbin:/usr/bin
+DAEMON=/usr/sbin/clamav-milter
+DESC="Sendmail milter plugin for ClamAV"
+BASENAME=clamav-milter
+CLAMAVCONF=#{clamav_milter_conf}
+DEFAULT=/etc/default/clamav-milter
+SUPERVISOR=/usr/bin/daemon
+SUPERVISORPIDFILE="/var/run/clamav/daemon-clamav-milter.pid"
+SUPERVISORARGS="-F $SUPERVISORPIDFILE --name=$BASENAME --respawn"
+CLAMAVDAEMONUPGRADE="/var/run/clamav-daemon-being-upgraded"
+
+[ -x "$DAEMON" ] || exit 0
+[ ! -r $DEFAULT ] || . $DEFAULT
+
+. /lib/lsb/init-functions
+
+if [ ! -f "$CLAMAVCONF" ]; then
+  log_failure_msg "There is no configuration file for clamav-milter."
+  log_failure_msg "Please either dpkg-reconfigure $DESC, or copy the example from"
+  log_failure_msg "/usr/share/doc/clamav-milter/examples/ to $CLAMAVCONF and run"
+  log_failure_msg "'/etc/init.d/clamav-milter start'"
+  exit 0
+fi
+
+slurp_config()
+{
+  CLAMAVCONF="$1"
+}
+
+slurp_config "$CLAMAVCONF"
+[ -n "$User" ] || User=clamav
+
+if [ -n "$Example" ]; then
+  log_failure_msg "$DESC is not configured."
+  log_failure_msg "Please edit $CLAMAVCONF and run '/etc/init.d/clamav-milter start'"
+  exit 0
+fi
+
+if [ -z "$PidFile" ]; then
+  PIDFILE=/var/run/clamav/clamav-milter.pid
+else
+  PIDFILE="$PidFile"
+fi
+
+if [ -z "$MilterSocket" ]; then
+  SOCKET=local:/var/run/clamav/clamav-milter.ctl
+else
+  SOCKET="$MilterSocket"
+fi
+
+case "$SOCKET" in
+  /*)
+  SOCKET_PATH="$SOCKET"
+  SOCKET="local:$SOCKET"
+  ;;
+  *)
+  SOCKET_PATH=`echo $SOCKET | sed -e s/local\://`
+  # If the socket is type inet: we don't care - we can't rm -f that later :)
+  ;;
+esac
+EOS
   end
 end
