@@ -43,6 +43,7 @@ struct _MilterManagerChildPrivate
     gchar *command_options;
     gboolean search_path;
     MilterStatus fallback_status;
+    gboolean evaluation_mode;
 };
 
 enum
@@ -53,7 +54,8 @@ enum
     PROP_COMMAND_OPTIONS,
     PROP_WORKING_DIRECTORY,
     PROP_SEARCH_PATH,
-    PROP_FALLBACK_STATUS
+    PROP_FALLBACK_STATUS,
+    PROP_REPUTATION_MODE
 };
 
 MILTER_DEFINE_ERROR_EMITTABLE_TYPE(MilterManagerChild,
@@ -126,6 +128,13 @@ milter_manager_child_class_init (MilterManagerChildClass *klass)
                              G_PARAM_READWRITE);
     g_object_class_install_property(gobject_class, PROP_FALLBACK_STATUS, spec);
 
+    spec = g_param_spec_boolean("evaluation-mode",
+                                "Reputation mode",
+                                "Whether the result of the child is used or not",
+                                FALSE,
+                                G_PARAM_READWRITE);
+    g_object_class_install_property(gobject_class, PROP_REPUTATION_MODE, spec);
+
     g_type_class_add_private(gobject_class,
                              sizeof(MilterManagerChildPrivate));
 }
@@ -142,6 +151,7 @@ milter_manager_child_init (MilterManagerChild *milter)
     priv->command_options = NULL;
     priv->search_path = TRUE;
     priv->fallback_status = MILTER_STATUS_ACCEPT;
+    priv->evaluation_mode = FALSE;
 }
 
 static void
@@ -212,6 +222,9 @@ set_property (GObject      *object,
     case PROP_FALLBACK_STATUS:
         priv->fallback_status = g_value_get_enum(value);
         break;
+    case PROP_REPUTATION_MODE:
+        priv->evaluation_mode = g_value_get_boolean(value);
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
         break;
@@ -246,6 +259,9 @@ get_property (GObject    *object,
     case PROP_FALLBACK_STATUS:
         g_value_set_enum(value, priv->fallback_status);
         break;
+    case PROP_REPUTATION_MODE:
+        g_value_set_boolean(value, priv->evaluation_mode);
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
         break;
@@ -305,6 +321,19 @@ milter_manager_child_get_fallback_status (MilterManagerChild *milter)
     return MILTER_MANAGER_CHILD_GET_PRIVATE(milter)->fallback_status;
 }
 
+void
+milter_manager_child_set_evaluation_mode (MilterManagerChild *milter,
+                                          gboolean evaluation_mode)
+{
+    MILTER_MANAGER_CHILD_GET_PRIVATE(milter)->evaluation_mode = evaluation_mode;
+}
+
+gboolean
+milter_manager_child_is_evaluation_mode (MilterManagerChild *milter)
+{
+    return MILTER_MANAGER_CHILD_GET_PRIVATE(milter)->evaluation_mode;
+}
+
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
