@@ -66,6 +66,8 @@ struct _MilterManagerConfigurationPrivate
     gchar *pid_file;
     guint maintenance_interval;
     guint suspend_time_on_unacceptable;
+    guint max_connections;
+    guint max_file_descriptors;
     guint processed_sessions;
     gchar *custom_configuration_directory;
 };
@@ -93,6 +95,8 @@ enum
     PROP_PID_FILE,
     PROP_MAINTENANCE_INTERVAL,
     PROP_SUSPEND_TIME_ON_UNACCEPTABLE,
+    PROP_MAX_CONNECTIONS,
+    PROP_MAX_FILE_DESCRIPTORS,
     PROP_PROCESSED_SESSIONS,
     PROP_CUSTOM_CONFIGURATION_DIRECTORY
 };
@@ -318,6 +322,28 @@ milter_manager_configuration_class_init (MilterManagerConfigurationClass *klass)
                                     PROP_SUSPEND_TIME_ON_UNACCEPTABLE,
                                     spec);
 
+    spec = g_param_spec_uint("max-connections",
+                             "Max connections",
+                             "Max number of concurrent connections.",
+                             0,
+                             G_MAXUINT,
+                             MILTER_CLIENT_DEFAULT_MAX_CONNECTIONS,
+                             G_PARAM_READWRITE | G_PARAM_CONSTRUCT);
+    g_object_class_install_property(gobject_class,
+                                    PROP_MAX_CONNECTIONS,
+                                    spec);
+
+    spec = g_param_spec_uint("max-file-descriptors",
+                             "Max file descriptors",
+                             "Max number of concurrent file descriptors.",
+                             0,
+                             G_MAXUINT,
+                             0,
+                             G_PARAM_READWRITE | G_PARAM_CONSTRUCT);
+    g_object_class_install_property(gobject_class,
+                                    PROP_MAX_FILE_DESCRIPTORS,
+                                    spec);
+
     spec = g_param_spec_string("custom-configuration-directory",
                                "Directory for custom configuration",
                                "The directory for custom configuration",
@@ -359,6 +385,9 @@ milter_manager_configuration_init (MilterManagerConfiguration *configuration)
     priv->maintenance_interval = DEFAULT_MAINTENANCE_INTERVAL;
     priv->suspend_time_on_unacceptable =
         MILTER_CLIENT_DEFAULT_SUSPEND_TIME_ON_UNACCEPTABLE;
+    priv->max_connections =
+        MILTER_CLIENT_DEFAULT_MAX_CONNECTIONS;
+    priv->max_file_descriptors = 0;
     priv->processed_sessions = 0;
     priv->custom_configuration_directory = NULL;
 
@@ -482,6 +511,14 @@ set_property (GObject      *object,
         milter_manager_configuration_set_suspend_time_on_unacceptable(
             config, g_value_get_uint(value));
         break;
+    case PROP_MAX_CONNECTIONS:
+        milter_manager_configuration_set_max_connections(
+            config, g_value_get_uint(value));
+        break;
+    case PROP_MAX_FILE_DESCRIPTORS:
+        milter_manager_configuration_set_max_file_descriptors(
+            config, g_value_get_uint(value));
+        break;
     case PROP_CUSTOM_CONFIGURATION_DIRECTORY:
         milter_manager_configuration_set_custom_configuration_directory(
             config, g_value_get_string(value));
@@ -562,6 +599,12 @@ get_property (GObject    *object,
     case PROP_SUSPEND_TIME_ON_UNACCEPTABLE:
         g_value_set_uint(value, priv->suspend_time_on_unacceptable);
         break;
+    case PROP_MAX_CONNECTIONS:
+        g_value_set_uint(value, priv->max_connections);
+        break;
+    case PROP_MAX_FILE_DESCRIPTORS:
+        g_value_set_uint(value, priv->max_file_descriptors);
+        break;
     case PROP_CUSTOM_CONFIGURATION_DIRECTORY:
         g_value_set_string(value, priv->custom_configuration_directory);
         break;
@@ -1235,6 +1278,44 @@ milter_manager_configuration_set_suspend_time_on_unacceptable (MilterManagerConf
     priv->suspend_time_on_unacceptable = suspend_time;
 }
 
+guint
+milter_manager_configuration_get_max_connections (MilterManagerConfiguration *configuration)
+{
+    MilterManagerConfigurationPrivate *priv;
+
+    priv = MILTER_MANAGER_CONFIGURATION_GET_PRIVATE(configuration);
+    return priv->max_connections;
+}
+
+void
+milter_manager_configuration_set_max_connections (MilterManagerConfiguration *configuration,
+                                                               guint suspend_time)
+{
+    MilterManagerConfigurationPrivate *priv;
+
+    priv = MILTER_MANAGER_CONFIGURATION_GET_PRIVATE(configuration);
+    priv->max_connections = suspend_time;
+}
+
+guint
+milter_manager_configuration_get_max_file_descriptors (MilterManagerConfiguration *configuration)
+{
+    MilterManagerConfigurationPrivate *priv;
+
+    priv = MILTER_MANAGER_CONFIGURATION_GET_PRIVATE(configuration);
+    return priv->max_file_descriptors;
+}
+
+void
+milter_manager_configuration_set_max_file_descriptors (MilterManagerConfiguration *configuration,
+                                                               guint suspend_time)
+{
+    MilterManagerConfigurationPrivate *priv;
+
+    priv = MILTER_MANAGER_CONFIGURATION_GET_PRIVATE(configuration);
+    priv->max_file_descriptors = suspend_time;
+}
+
 const gchar *
 milter_manager_configuration_get_custom_configuration_directory (MilterManagerConfiguration *configuration)
 {
@@ -1588,6 +1669,8 @@ milter_manager_configuration_clear (MilterManagerConfiguration *configuration)
     priv->maintenance_interval = DEFAULT_MAINTENANCE_INTERVAL;
     priv->suspend_time_on_unacceptable =
         MILTER_CLIENT_DEFAULT_SUSPEND_TIME_ON_UNACCEPTABLE;
+    priv->max_connections = 0;
+    priv->max_file_descriptors = 0;
 }
 
 void
