@@ -158,7 +158,9 @@ cb_body (MilterClientContext *context, const gchar *chunk, gsize size,
 }
 
 static MilterStatus
-cb_end_of_message (MilterClientContext *context, gpointer user_data)
+cb_end_of_message (MilterClientContext *context,
+                   const gchar *chunk, gsize size,
+                   gpointer user_data)
 {
     n_end_of_messages++;
     append_private_data(context, "end of message");
@@ -167,7 +169,8 @@ cb_end_of_message (MilterClientContext *context, gpointer user_data)
 }
 
 static MilterStatus
-cb_abort (MilterClientContext *context, gpointer user_data)
+cb_abort (MilterClientContext *context, MilterClientContextState state,
+          gpointer user_data)
 {
     n_aborts++;
     append_private_data(context, "abort");
