@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2008-2009  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -150,6 +150,28 @@ sockaddr_in6_new (guint16 port, const gchar *host)
     return (struct sockaddr *)address;
 }
 
+static struct sockaddr *
+sockaddr_unknown_new (void)
+{
+    struct sockaddr *address;
+
+    address = g_new0(struct sockaddr, 1);
+    address->sa_family = AF_UNSPEC;
+
+    return address;
+}
+
+static struct sockaddr *
+sockaddr_unexpected_new (int family)
+{
+    struct sockaddr *address;
+
+    address = g_new0(struct sockaddr, 1);
+    address->sa_family = family;
+
+    return address;
+}
+
 static TestData *
 test_data_new (const gchar *spec,
                struct sockaddr *expected_address,
@@ -415,6 +437,16 @@ data_address_to_spec (void)
                                sockaddr_un_new("/tmp/xxx.sock"),
                                NULL),
                  test_data_free,
+                 "unknown",
+                 test_data_new("unknown",
+                               sockaddr_unknown_new(),
+                               NULL),
+                 test_data_free,
+                 "unexpected",
+                 test_data_new("unexpected:100",
+                               sockaddr_unexpected_new(100),
+                               NULL),
+                 test_data_free,
                  "no content",
                  test_data_new(NULL,
                                NULL,
